import type { StrategyVerifyCallback } from "remix-auth";
import type { OAuth2Profile, OAuth2StrategyVerifyParams } from "remix-auth-oauth2";
import { OAuth2Strategy } from "remix-auth-oauth2";
export interface KeycloakStrategyOptions {
    useSSL: boolean;
    domain: string;
    realm: string;
    clientID: string;
    clientSecret: string;
    callbackURL: string;
    scope?: string;
}
export interface KeycloakExtraParams extends Record<string, string | number> {
    id_token: string;
    scope: string;
    expires_in: 86400;
    token_type: "Bearer";
}
export interface KeycloakProfile extends OAuth2Profile {
    id: string;
    displayName: string;
    name: {
        familyName: string;
        givenName: string;
    };
    emails: [{
        value: string;
    }];
    _json: {
        sub: string;
        email: string;
        email_verified: boolean;
        preferred_username: string;
        name: string;
        given_name: string;
        family_name: string;
    };
}
export declare class KeycloakStrategy<User> extends OAuth2Strategy<User, KeycloakProfile, KeycloakExtraParams> {
    name: string;
    private userInfoURL;
    private scope;
    constructor(options: KeycloakStrategyOptions, verify: StrategyVerifyCallback<User, OAuth2StrategyVerifyParams<KeycloakProfile, KeycloakExtraParams>>);
    protected authorizationParams(): URLSearchParams;
    protected userProfile(accessToken: string): Promise<KeycloakProfile>;
}
